==> dar_2.2.1.orig.tar.gz: dar-2.2.1/src/testing/test_deci.cpp <==
/*********************************************************************/
// dar - disk archive - a backup/restoration program
// Copyright (C) 2002-2052 Denis Corbin
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// to contact the author : dar.linux@free.fr
/*********************************************************************/
// $Id: test_deci.cpp,v 1.6 2003/10/18 14:43:07 edrusb Rel $
//
/*********************************************************************/

#include "../my_config.h"
#include <iostream>

#include "test_memory.hpp"
#include "deci.hpp"

using namespace libdar;
using namespace std;

static void f1();

int main()
{
    MEM_BEGIN;
    MEM_IN;
    f1();
    MEM_OUT;
    MEM_END;
}

static void f1()
{
    deci d1 = string("00001");
    infinint t = 3;
    deci d2 = t;
    deci d3 = infinint(125);
    U_I c;
    
    cout << d1.human() << endl;
    cout << d2.human() << endl;
    cout << d3.human() << endl;

    c = d1.computer() % 200;
    c = d2.computer() % 200;
    c = d3.computer() % 200;
}

==> dar_2.4.15.orig.tar.gz: dar-2.4.15/src/testing/test_deci.cpp <==
/*********************************************************************/
// dar - disk archive - a backup/restoration program
// Copyright (C) 2002-2052 Denis Corbin
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// to contact the author : http://dar.linux.free.fr/email.html
/*********************************************************************/

#include "../my_config.h"
#include <iostream>

#include "deci.hpp"

using namespace libdar;
using namespace std;

static void f1();

int main()
{
    f1();
}

static void f1()
{
    libdar::deci d1 = string("00001");
    infinint t = 3;
    libdar::deci d2 = t;
    libdar::deci d3 = infinint(125);
    U_I c;

    cout << d1.human() << endl;
    cout << d2.human() << endl;
    cout << d3.human() << endl;

    c = d1.computer() % 200;
    c = d2.computer() % 200;
    c = d3.computer() % 200;
}
